==> jboss-ejb3-effigy-common-0.1.0-sources.jar: org/jboss/ejb3/effigy/common/JBossSessionBeanEffigy.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright (c) 2010, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @authors tag. See the copyright.txt in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.ejb3.effigy.common;

import org.jboss.ejb3.effigy.SessionBeanEffigy;
import org.jboss.metadata.ejb.jboss.JBossSessionBeanMetaData;

import java.lang.reflect.Method;

/**
 * @author <a href="mailto:cdewolf@redhat.com">Carlo de Wolf</a>
 */
public class JBossSessionBeanEffigy extends JBossEnterpriseBeanEffigy
   implements SessionBeanEffigy
{
   public JBossSessionBeanEffigy(ClassLoader classLoader, JBossSessionBeanMetaData beanMetaData)
           throws ClassNotFoundException
   {
      super(classLoader, beanMetaData);
   }

   @Override
   public Method getAfterBeginMethod()
   {
      return null;
   }

   @Override
   public Method getAfterCompletionMethod()
   {
      return null;
   }

   @Override
   public Method getBeforeCompletionMethod()
   {
      return null;
   }
}

==> jboss-ejb3-effigy-common-0.2.0-sources.jar: org/jboss/ejb3/effigy/common/JBossSessionBeanEffigy.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright (c) 2010, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @authors tag. See the copyright.txt in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.ejb3.effigy.common;

import org.jboss.ejb3.effigy.AccessTimeoutEffigy;
import org.jboss.ejb3.effigy.SessionBeanEffigy;
import org.jboss.ejb3.effigy.StatefulTimeoutEffigy;
import org.jboss.metadata.ejb.jboss.JBossSessionBeanMetaData;

import java.lang.reflect.Method;

/**
 * @author <a href="mailto:cdewolf@redhat.com">Carlo de Wolf</a>
 */
public class JBossSessionBeanEffigy extends JBossEnterpriseBeanEffigy
   implements SessionBeanEffigy
{
   public JBossSessionBeanEffigy(ClassLoader classLoader, JBossSessionBeanMetaData beanMetaData)
           throws ClassNotFoundException
   {
      super(classLoader, beanMetaData);
   }

   @Override
   public AccessTimeoutEffigy getAccessTimeout(Method method)
   {
      return null;
   }

   @Override
   public Method getAfterBeginMethod()
   {
      return null;
   }

   @Override
   public Method getAfterCompletionMethod()
   {
      return null;
   }

   @Override
   public Method getBeforeCompletionMethod()
   {
      return null;
   }

   @Override
   public StatefulTimeoutEffigy getStatefulTimeout()
   {
      return null;
   }
}
